@@ -2,7 +2,7 @@
 #include "xctype.h"
 #include "xstring.h"
 
-RCSID("$Id: fix.c,v 1.5 1996/05/03 20:14:42 beebe Exp beebe $")
+RCSID("$Id: fix.c,v 1.6 1999/05/20 13:36:45 beebe Exp beebe $")
 
 #include "yesorno.h"
 #include "token.h"
@@ -258,22 +258,28 @@ fix_month(VOID)			/* convert full month names to macros*/
 		    (strnicmp(month_pair[k].old_name,token,token_length) == 0))
 		{			/* change "January" to jan etc. */
 		    (void)strcpy(s,"\" # ");
+		    if ((s >= (shared_string + 1)) &&
+			(strncmp(s-1,"\"\" # ",5) == 0))
+		    {	/* eliminate any concatenation with an empty string */
+			s--;
+			*s = '\0';	/* need string terminator for strcat() */
+		    }
 		    (void)strcat(s,month_pair[k].new_name);
 		    (void)strcat(s," # \"");
 		    s = strchr(s,'\0');
 		    token_length = 0;	/* so we don't copy twice at loop end */
-		    break;
+		    break;		/* exit loop after first substitution */
 		}
 	    }				/* end for (k = 0, ...) */
 	    (void)strncpy(s,token,token_length); /* no definition, just copy */
 	    s += token_length;
 	}
+	if ((s >= (shared_string + 5)) && (strncmp(s-5," # \"\"",5) == 0))
+	    s -= 5;	/* eliminate any concatenation with an empty string */
     }
     *s = '\0';				/* supply string terminator */
     k = (size_t)(s - shared_string);
     s = shared_string;
-    if (STREQUAL(&s[k-5]," # \"\""))
-	s[k-5] = '\0';			/* discard final empty string */
     if (strncmp(s,"\"\" # ",5) == 0)
 	(void)strcpy(current_value,&s[5]); /* discard initial empty string */
     else
@@ -529,58 +535,75 @@ size_t *p_len;
     /* characters are considered non-letters. This code is vaguely modelled */
     /* on Standard C's strtok() function. */
 
+    /* Bug fix for version 2.11.4 [09-May-1998]:  Prior to this version,
+       a value
+
+           mar # "\slash" # apr
+
+       would be incorrectly transformed
+
+           month = mar # "\slash" # " # apr # "
+
+       because in_quoted_string was incorrect for the remainder of
+       the value.
+
+       If the input value was changed to
+
+           mar # "\slash " # apr
+
+       then that space inside the quoted string preserved the
+       correctness of in_quoted_string, and the output was correct.
+
+       For version 2.11.4, the body of this function has been entirely
+       rewritten to simplify the logic, and ensure its correctness. */
+
     static int b_level = 0;		/* remembered across calls */
     static YESorNO in_quoted_string = NO; /* remembered across calls */
-    static const char *last = (const char *)NULL; /* remembered across calls */
+    static const char *next = (const char *)NULL; /* remembered across calls */
     const char *token;			/* pointer to returned token */
 
     if (s != (const char*)NULL)		/* do we have a new s[]? */
     {
-	last = s;			/* yes, remember it */
+	next = s;			/* yes, remember it */
 	b_level = 0;			/* and reinitialize state */
 	in_quoted_string = NO;		/* variables */
     }
 
-    for (*p_len = 0, token = last; (last != (const char*)NULL) && *last ; )
+    *p_len = 0;
+    token = next;
+
+    switch (*next)
     {
-	switch (*last)
-	{
-	case '"':
-	    if (b_level == 0)
-		in_quoted_string = (in_quoted_string == YES) ? NO : YES;
-	    break;
+    case '"':
+	if (b_level == 0)
+	    in_quoted_string = (in_quoted_string == YES) ? NO : YES;
+	break;
 
-	case '{':			/* '}' for brace balance */
-	    b_level++;
-	    break;
+    case '{':				/* '}' for brace balance */
+	b_level++;
+	break;
 					/* '{' for brace balance */
-	case '}':
-	    b_level--;
-	    break;
+    case '}':
+	b_level--;
+	break;
 
-	default:
-	    break;
-	}
+    default:
+	break;
+    }
+
+#define ADVANCE ((*p_len)++, next++)
+
+    if ((in_quoted_string == YES) && Isalpha(*next))
+    {			/* collect possibly-dot-terminated alphabetic token */
+	while (Isalpha(*next))
+	    ADVANCE;
+	if (*next == '.')
+	    ADVANCE;
+    }
+    else if (*next != '\0')		/* collect single-character token */
+	ADVANCE;
+
+#undef ADVANCE
 
-	if ((in_quoted_string == YES) && Isalpha(*last))
-	{
-	    (*p_len)++;			/* count this token character */
-	    ++last;			/* collect multi-letter token */
-	}
-	else if (*last == '.')		/* then period ends a token */
-	{
-	    (*p_len)++;			/* count this token character */
-	    ++last;
-	    break;
-	}
-	else if (*p_len == 0)		/* then have 1-char token */
-	{
-	    (*p_len)++;			/* count this token character */
-	    ++last;
-	    break;
-	}
-	else				/* looked ahead too far */
-	    break;
-    }					/* end for (*p_len ...) */
     return ((*p_len == 0) ? (const char*)NULL : token);
 }
