@@ -2,23 +2,26 @@
  @C-file{
     author              = "Nelson H. F. Beebe",
     version             = "1.01",
-    date                = "03 October 1995",
-    time                = "23:06:05 MDT",
+    date                = "09 May 1998",
+    time                = "22:56:42 MDT",
     filename            = "isbn.c",
     address             = "Center for Scientific Computing
-                           Department of Mathematics
-                           University of Utah
-                           Salt Lake City, UT 84112
-                           USA",
+			   University of Utah
+			   Department of Mathematics, 322 INSCC
+			   155 S 1400 E RM 233
+			   Salt Lake City, UT 84112-0090
+			   USA",
     telephone           = "+1 801 581 5254",
-    FAX                 = "+1 801 581 4148",
-    checksum            = "08923 790 2623 20918",
-    email               = "beebe@math.utah.edu (Internet)",
+    FAX                 = "+1 801 585 1640, +1 801 581 4148",
+    URL                 = "http://www.math.utah.edu/~beebe",
+    checksum            = "54390 923 3137 25116",
+    email               = "beebe@math.utah.edu, beebe@acm.org,
+                           beebe@ieee.org (Internet)",
     codetable           = "ISO/ASCII",
     keywords            = "bibliography, ISBN, hyphenation",
     supported           = "yes",
     docstring           = "This file contains code for hyphenating
-                           International Standard Book Numbers (ISBNs),
+			   International Standard Book Numbers (ISBNs),
 			   using the function ISBN_hyphenate(s,t,maxs).
 			   No other public objects are defined by this
 			   file.
@@ -39,11 +42,11 @@
 			   originally incorrect, or missing.
 
 			   The checksum field above contains a CRC-16
-                           checksum as the first value, followed by the
-                           equivalent of the standard UNIX wc (word
-                           count) utility output of lines, words, and
-                           characters.  This is produced by Robert
-                           Solovay's checksum utility.",
+			   checksum as the first value, followed by the
+			   equivalent of the standard UNIX wc (word
+			   count) utility output of lines, words, and
+			   characters.  This is produced by Robert
+			   Solovay's checksum utility.",
  }
 ***********************************************************************/
 
@@ -52,7 +55,7 @@
 #include "xstring.h"
 #include "xctype.h"
 
-RCSID("$Id: isbn.c,v 1.3 1996/05/03 20:16:23 beebe Exp beebe $")
+RCSID("$Id: isbn.c,v 1.4 1999/05/20 13:27:53 beebe Exp beebe $")
 
 #define isISBNdigit(c)	(isdigit(c) || ((c) == 'X') || ((c) == 'x'))
 
@@ -165,7 +168,9 @@ const char *ISBN;
 	const char *end;
     } ISBN_range[] =
     {
-     /* Australia, Canada (English), New Zealand, South Africa, UK, Zimbabwe */
+     /* Australia, Canada (English), Gibraltar, Ireland, New Zealand,
+	South Africa, Swaziland, United Kingdom, United States of America,
+	Zimbabwe */
      { "0-00",			"0-19" },
      { "0-200",			"0-698" },
      { "0-7000",		"0-8499" },
@@ -173,7 +178,9 @@ const char *ISBN;
      { "0-900000",		"0-949999" },
      { "0-9500000",		"0-9801223" },
 
-     /* Australia, Canada (English), New Zealand, South Africa, UK, Zimbabwe */
+     /* Australia, Canada (English), Gibraltar, Ireland, New Zealand,
+	South Africa, Swaziland, United Kingdom, United States of America,
+	Zimbabwe */
      { "1-55000",		"1-86957" },
      { "1-869800",		"1-895682" },
 
@@ -200,8 +207,10 @@ const char *ISBN;
      { "4-87000",		"4-89829" },
      { "4-900000",		"4-949999" },
 
-     /* Commonwealth of Independent States and Georgia, Estonia, */
-     /* Latvia, Lithuania, USSR */
+     /* Azerbaijan, Belarus, Commonwealth of Independent States, Estonia,
+	Georgia, Kazakhstan, Kyrgyzstan, Latvia, Lithuania, Tajikistan,
+	Turkmenistan, Uzbekistan */
+
      { "5-01",			"5-12" },
      { "5-200",			"5-690" },
      { "5-7000",		"5-8396" },
@@ -256,7 +265,7 @@ const char *ISBN;
      { "85-85000",		"85-85457" },
      { "85-900000",		"85-900051" },
 
-     /* Yugoslavia */
+     /* Bosnia and Herzegovina, Croatia, Macedonia, Slovenia, Yugoslavia */
      { "86-03",			"86-27" },
      { "86-301",		"86-455" },
      { "86-7001",		"86-7861" },
@@ -321,6 +330,9 @@ const char *ISBN;
      { "952-6666",		"952-6666" },
      { "952-9500",		"952-9714" },
 
+     /* Croatia (publisher range unknown) */
+     { "953-00",		"953-99" },
+
      /* Bulgaria */
      { "954-0",			"954-0" /* <--no assignments yet */ },
 
@@ -357,6 +369,9 @@ const char *ISBN;
      { "960-7000",		"960-8499" },
      { "960-85000",		"960-85203" },
 
+     /* Slovenia (publisher range unknown) */
+     { "961-00",		"961-99" },
+
      /* Hong Kong */
      { "962-00",		"962-19" },
      { "962-201",		"962-474" },
@@ -368,10 +383,16 @@ const char *ISBN;
      { "963-700",		"963-8481" },
      { "963-85000",		"963-85084" },
 
+     /* Iran (publisher range unknown) */
+     { "964-00",		"964-99" },
+
      /* Israel */
      { "965-01",		"965-19" },
      { "965-207",		"965-442" },
 
+     /* Ukraine  (publisher range unknown) */
+     { "966-00",		"966-99" },
+
      /* Malaysia */
      { "967-60",		"967-89" },
      { "967-900",		"967-989" },
@@ -434,7 +455,6 @@ const char *ISBN;
 
      /* Egypt */
      { "977-01",		"977-17" },
-
      { "977-200",		"977-457" },
      { "977-5000",		"977-5235" },
 
@@ -473,9 +493,21 @@ const char *ISBN;
      { "984-400",		"984-556" },
      { "984-8005",		"984-8085" },
 
+     /* Belarus (publisher range unknown) */
+     { "985-00",		"985-99" },
+
      /* Argentina */
      { "987-0",			"987-0" /* <--no assignments yet */ },
 
+     /* Libya (publisher range unknown) */
+     { "9959-0",		"9959-9" },
+
+     /* Algeria (publisher range unknown) */
+     { "9961-0",		"9961-9" },
+
+     /* Panama (publisher range unknown) */
+     { "9962-0",		"9962-9" },
+
      /* Cyprus */
      { "9963-0",		"9963-1" },
      { "9963-30",		"9963-44" },
@@ -487,20 +519,32 @@ const char *ISBN;
      { "9964-70",		"9964-94" },
      { "9964-950",		"9964-990" },
 
+     /* Kazakhstan (publisher range unknown) */
+     { "9965-0",		"9965-9" },
+
      /* Kenya */
      { "9966-20",		"9966-49" },
      { "9966-830",		"9966-882" },
      { "9966-9840",		"9966-9874" },
 
+     /* Kyrgyzstan (publisher range unknown) */
+     { "9967-0",		"9967-9" },
+
      /* Costa Rica */
      { "9968-9702",		"9968-9703" },
 
+     /* Uganda (publisher range unknown) */
+     { "9970-0",		"9970-9" },
+
      /* Singapore */
      { "9971-0",		"9971-4" },
      { "9971-60",		"9971-89" },
      { "9971-900",		"9971-989" },
      { "9971-9900",		"9971-9924" },
 
+     /* Peru (publisher range unknown) */
+     { "9972-0",		"9972-9" },
+
      /* Tunisia */
      { "9973-10",		"9973-18" },
      { "9973-700",		"9973-925" },
@@ -512,6 +556,9 @@ const char *ISBN;
      { "9974-550",		"9974-580" },
      { "9974-7500",		"9974-7505" },
 
+     /* Moldova (publisher range unknown) */
+     { "9975-0",		"9975-9" },
+
      /* Tanzania */
      { "9976-1",		"9976-5" },
      { "9976-60",		"9976-84" },
@@ -551,6 +598,15 @@ const char *ISBN;
      { "9983-85",		"9983-87" },
      { "9983-9900",		"9983-9901" },
 
+     /* Latvia (publisher range unknown) */
+     { "9984-0",		"9984-9" },
+
+     /* Estonia (publisher range unknown) */
+     { "9985-0",		"9985-9" },
+
+     /* Lithuania (publisher range unknown) */
+     { "9986-0",		"9986-9" },
+
      /* Tanzania */
      { "9987-30",		"9987-30" },
      { "9987-550",		"9987-583" },
@@ -559,6 +615,9 @@ const char *ISBN;
      /* Ghana */
      { "9988-0",		"9988-0" /* <--no assignments yet */ },
 
+     /* Macedonia (publisher range unknown) */
+     { "9989-0",		"9989-9" },
+
      /* Mauritius */
      { "99903-0",		"99903-0" /* <--no assignments yet */ },
 
@@ -571,6 +630,9 @@ const char *ISBN;
      { "99908-11",		"99908-29" },
      { "99908-900",		"99908-900" },
 
+     /* Malta (publisher range unknown) */
+     { "99909-0",		"99909-9" },
+
      /* Lesotho */
      { "99911-00",		"99911-32" },
      { "99911-600",		"99911-860" },
@@ -598,11 +660,73 @@ const char *ISBN;
      { "99916-30",		"99916-35" },
      { "99916-700",		"99916-704" },
 
+     /* Benin (publisher range unknown) */
+     { "99919-0",		"99919-9" },
+
      /* Andorra */
      { "99920-0",		"99920-2" },
      { "99920-50",		"99920-55" },
      { "99920-900",		"99920-904" },
 
+     /* Qatar (publisher range unknown) */
+     { "99921-0",		"99921-9" },
+
+     /* Guatemala (publisher range unknown) */
+     { "99922-0",		"99922-9" },
+
+     /* Nicaragua (publisher range unknown) */
+     { "99924-0",		"99924-9" },
+
+     /* From http://www.bowker.com/standards/home/isbn/international/hyphenation-instructions.html
+	The publisher prefix ranges in the English group (U.S., U.K.,
+	Canada, Australia, New Zealand, etc) are as follows:
+
+	     Group                   If Number Ranges         Insert Hyphens
+	     Identifier "0"           are Between              After
+	     -------------------------------------------------------------------
+	     00.......19                00-19             1st  3rd  9th digit
+	     200......699               20-69              "   4th       "
+	     7000.....8499              70-84              "   5th       "
+	     85000....89999             85-89              "   6th       "
+	     900000...949999            90-94              "   7th       "
+	     9500000..9999999           95-99              "   8th       "
+
+
+
+	     Group                   If Number Ranges        Insert Hyphens
+	     Identifier "1"           are Between             After
+	     -------------------------------------------------------------------
+	     55000....86979           5500-8697           1st  6th  9th digit
+	     869800...998999          8698-9989            "   7th       "
+	     9990000..9999999         9990-9999            "   8th       "
+
+
+
+	       The following table gives the range distribution of the group identifiers:
+
+					0 - 7
+				       80 - 94
+				      950 - 995
+				     9960 - 9989
+				    99900 - 99999
+
+	These ranges are already partially covered by ranges above, but
+	we include them here for completeness, unless they are identical
+	to one above, in which case, they are commented out.  I have yet
+	to find comparable data for other language groups. */
+
+
+     /* { "0-00",		"0-19" }, */
+     { "0-200",			"0-699" },
+     /* { "0-7000",		"0-8499" }, */
+     { "0-85000",		"0-89999" },
+     /* { "0-900000",		"0-949999" }, */
+     { "0-9500000",		"0-9999999" },
+
+     { "1-55000",		"1-86979" },
+     { "1-869800",		"1-998999" },
+     { "1-9990000",		"1-9999999" },
+
      { (const char*)NULL,	(const char*)NULL }
     };
 
@@ -637,7 +761,7 @@ const char *ISBN;
       The input ISBN can contain optional leading and trailing text,
       such as a line from a BibTeX .bib file, like this:
 
-         ISBN =         "0-387-09823-2 (paperback)",
+	 ISBN =         "0-387-09823-2 (paperback)",
 
      ******************************************************************/
 
@@ -653,15 +777,15 @@ const char *ISBN;
 	    new_ISBN[k++] = '-';
 	    prefix++;
 	}
-        else if (*prefix)
+	else if (*prefix)
 	{
 	    skip_non_ISBN_digit(ISBN);
 	    if (*ISBN == '\0')
 		break;
 	    new_ISBN[k++] = *ISBN++;
-    	    prefix++;
+	    prefix++;
 	    if ((*prefix == '\0') && (k < MAX_ISBN))
-    		new_ISBN[k++] = '-';
+		new_ISBN[k++] = '-';
 	}
 	else			/* past prefix */
 	{
@@ -680,7 +804,7 @@ const char *ISBN;
 	return ((const char*)&new_ISBN[0]);
     }
     else
-    	return ((const char*)NULL);
+	return ((const char*)NULL);
 }
 
 #if defined(HAVE_STDC)
@@ -792,7 +916,7 @@ const char *in_ISBN;
 	skip_non_ISBN_digit(in_ISBN);
 	*out_ISBN = *in_ISBN;
 	if (*in_ISBN == '\0')
-      	    break;
+	    break;
 	in_ISBN++;
 	out_ISBN++;
     }
