@@ -4,7 +4,7 @@
 /****************************** vmswild *******************************/
 /**********************************************************************/
 
-#include "os.h"
+#include <config.h>
 
 #if 0			/* BEGIN COMMENT SECTION */
 
@@ -29,7 +29,7 @@
 **
 **	(4) If a filename ends in a dot, remove it ("foo." -> "foo").
 **
-**      (5) Reorder routines alphabetically, and supply Standard C 
+**      (5) Reorder routines alphabetically, and supply Standard C
 **      function prototype declarations.
 **
 **	(6) Make all functions and global variables static (private),
@@ -93,7 +93,7 @@
 ** 	extern char **cmd_lin();
 **
 ** 	argv = cmd_lin( "", &argc, argv );
-** 	!* The first argument provides misc. options (not currenly used). *!
+** 	!* The first argument provides misc. options (not currently used). *!
 ** #endif !* VMS *!
 ** 	!* your routine *!
 ** }
@@ -161,7 +161,7 @@
  *	Un*x-style wildcards like [char-set].
  *	    (watch out for people who use `[' and `]' for directory names!!)
  *
- * This files also contains a special demonstartion program.  To use it type:
+ * This files also contains a special demonstration program.  To use it type:
  *	$ cc cmdlin/define:example
  *	$ link cmdlin,sys$input:/opt
  *	sys$share:vaxcrtl/share
@@ -201,51 +201,26 @@ static char version[] = /* (Not currently) printed inside "debug" option. */
   "cmd_lin() V2.0, Copyright (C) 1988 Eric Tye McQueen (3-Mar).";
 #endif /* 0 */
 
-static char rcsid[] = "$Id: vmswild.c,v 1.6 1992/11/15 16:59:38 beebe Exp beebe $";
+static char rcsid[] = "$Id: vmswild.c,v 1.2 1996/05/03 20:09:24 beebe Exp $";
 
-/* $Log: vmswild.c,v $
- * Revision 1.6  1992/11/15  16:59:38  beebe
- * Correct some function declarations converted incompletely during
- * the C++ conversion.  Add some more typecasts, using NULL instead of 0.
- * Remove static attribute from cmd_line() declaration.
- *
- * Revision 1.5  1992/10/08  01:42:01  beebe
- * Update for C++.
- * Modify some comments to avoid confusing preprocessors that
- * parse text lines between #if 0 ... #endif.
- *
- * Revision 1.4  1992/07/10  18:03:46  beebe
- * Add some typecasts.
- *
- * Revision 1.3  1992/03/10  00:33:33  beebe
- * *** empty log message ***
- *
- * Revision 1.2  1992/02/29  19:42:20  beebe
- * Update for version 3.0.114 [29-Feb-1992] following two-month
- * major overhaul and compilation testing on numerous machines.
- *
- * Revision 1.2  1992/02/29  19:42:20  beebe
- * Update for version 3.0.114 [29-Feb-1992] following two-month
- * major overhaul and compilation testing on numerous machines.
- * */ 
 
 #ifndef VMS	/* Should be changed to Standard C-conforming name soon. */
 
-/* Dummy version of cmd_lin() for non VAX C (nonVMS) systems: */
+/* Dummy version of cmd_lin() for non VAX C (non-VMS) systems: */
 
 char **
-#if STDC
+#if defined(HAVE_STDC)
 cmd_lin(
 char	*opt0,				/* Options specified in `main()' */
 int	*ainpc,				/* &main\argc (input and output) */
 char	**inpv				/* main\argv (input) */
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 cmd_lin( opt0, ainpc, inpv )
 char	*opt0;				/* Options specified in `main()' */
 int	*ainpc;				/* &main\argc (input and output) */
 char	**inpv;				/* main\argv (input) */
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
     return( inpv );
 }
@@ -253,11 +228,22 @@ char	**inpv;				/* main\argv (input) */
 #else  /* VMS */
 
 #include <stdio.h>	/* stdin stdout stderr */
-#include <ctype.h>	/* iscntrl() isascii() */
-#include <errno.h>	/* errno vaxc$errno */
 
+#if defined(HAVE_CTYPE_H)
+#include <ctype.h>
+#endif
+
+#if defined(HAVE_ERRNO_H)
+#include <errno.h>
+#endif
+
+#if defined(HAVE_STDLIB_H)
 #include <stdlib.h>
+#endif
+
+#if defined(HAVE_STRING_H)
 #include <string.h>
+#endif
 
 typedef	 char  bool;		/* Smallest addressable signed data type. */
 typedef	 unsigned char	 uchar;
@@ -271,7 +257,7 @@ typedef	 unsigned long	 ulong;
 struct descr {
 	ushort leng;	/* Length of data area (or string). */
 	uchar  type;	/* Type of data in area (dsc$k_dtype_t). */
-	uchar  class;	/* Class of desctiptor (dsc$k_class_s). */
+	uchar  class;	/* Class of descriptor (dsc$k_class_s). */
 	char  *addr;	/* Address of start of data area. */
 };
 globalvalue dsc$k_dtype_t; /* Text (data type) */
@@ -286,7 +272,6 @@ globalvalue dsc$k_class_s; /* Static (class) descriptor */
   { strlen(str), dsc$k_dtype_t, dsc$k_class_s, str }
 
 #define	  FNAMSIZ  1024 /* size of filename buffers (+1 for '\0') */
-#define	  LINSIZ   20480 /* maximum length of command line */
 
 /* Options that are set by an argument like "{opt1,!opt2,noopt3,opt4=val}":
  * (none of these are really supported in this release)
@@ -358,24 +343,28 @@ static char	**redirout(int *ainpc,char **inpv);
 static void	sigvms(uint stat);
 static char	*strsub(char *str, char *sub);
 
+#if defined(__ALPHA)
+void	lib$stop(int status_);
+#endif
+
 #ifdef TEST
 static void	dump(char *str);
 int		main(int argc,char **argv);
 #endif /* TEST */
 
 char **
-#if STDC
+#if defined(HAVE_STDC)
 cmd_lin(
 char	*opt0,				/* Options specified in `main()' */
 int	*ainpc,				/* &main\argc (input and output) */
 char	**inpv				/* main\argv (input) */
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 cmd_lin( opt0, ainpc, inpv )		/* returns new value for main\argv */
 char	*opt0;				/* Options specified in `main()' */
 int	*ainpc;				/* &main\argc (input and output) */
 char	**inpv;				/* main\argv (input) */
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
     int endc;	/* `endc' and `endv' will be `argc' and `argv' for main() */
     char **endv = add_arg((char*)NULL,&endc,(char**)NULL);
@@ -389,7 +378,7 @@ char	**inpv;				/* main\argv (input) */
 	else if(  *opt0	 )
 	{
 	    globalvalue ss$abort;
-	    fprintf( stderr, "%s (%s) %s.\n", "Invalid options string",
+	    (void)fprintf( stderr, "%s (%s) %s.\n", "Invalid options string",
 		    opt0, "specified in `main()'" );
 	    exit( ss$abort );
 	}
@@ -425,7 +414,7 @@ char	**inpv;				/* main\argv (input) */
 			}
 			else
 			{
-			    fprintf( stderr, "%s: No match.\n", *inpv );
+			    (void)fprintf( stderr, "%s: No match.\n", *inpv );
 			    endv = add_arg( *inpv, &endc, endv );
 			}
 		}
@@ -435,7 +424,7 @@ char	**inpv;				/* main\argv (input) */
 		++inpv;
 	}
 	if (  xtra  )	/* An extra block of pointers was malloc()ed */
-	    free( xtra );
+	    FREE( xtra );
 	*ainpc = endc;
 
 	return( endv );
@@ -447,18 +436,18 @@ char	**inpv;				/* main\argv (input) */
 
 /* Builds argc,argv type lists of strings: */
 static char **
-#if STDC
+#if defined(HAVE_STDC)
 add_arg(
   char *arg,	/* Argument to be added to the argument list */
   int *acnt,	/* Number of arguments currently in the argument list */
   char **ptrs	/* Array of pointers to the arguments */
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 add_arg( arg, acnt, ptrs )
   char *arg;	/* Argument to be added to the argument list */
   int *acnt;	/* Number of arguments currently in the argument list */
   char **ptrs;	/* Array of pointers to the arguments */
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
 # define ARGRP 64	/* number of string pointers allocated at a time */
 	if(  !ptrs  ) { /* Initialize a new argument list: */
@@ -476,18 +465,18 @@ add_arg( arg, acnt, ptrs )
 
 /* Creates a logical name. */
 static uint				/* Returns a VMS condition value. */
-#if STDC
+#if defined(HAVE_STDC)
 crelnm(
   char *table,
-  char *name, 
+  char *name,
   char *value
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 crelnm( table, name, value )
   char *table;
   char *name;
   char *value;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
   desc_str( tdsc, table );
   desc_str( ndsc, name );
@@ -511,14 +500,14 @@ crelnm( table, name, value )
 
 /* Same as malloc() except never returns NULL. */
 static void *
-#if STDC
+#if defined(HAVE_STDC)
 emalloc(
   unsigned siz
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 emalloc( siz )
   unsigned siz;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
   globalvalue ss$_insfmem;	/* Insufficient dynamic memory error */
   register void *p = malloc( siz );
@@ -529,16 +518,16 @@ emalloc( siz )
 
 /* Same as realloc() except never returns NULL. */
 static void *
-#if STDC
+#if defined(HAVE_STDC)
 erealloc(
   void *ptr,
   unsigned siz
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 erealloc( ptr, siz )
   void *ptr;
   unsigned siz;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
   globalvalue ss$_insfmem;	/* Insufficient dynamic memory error */
   register void *p = realloc( ptr, siz );
@@ -548,14 +537,14 @@ erealloc( ptr, siz )
 }
 
 static char*
-#if STDC
+#if defined(HAVE_STDC)
 expand_logical(
 char	*logname
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 expand_logical(logname)		/* return recursively expanded logical name */
 char	*logname;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
     char	*p;
     char	*colon;
@@ -572,28 +561,28 @@ char	*logname;
 
 
 static bool	/* Returns 1 if `name' looks like a wild-carded file name. */
-#if STDC
+#if defined(HAVE_STDC)
 iswild(
   char *name
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 iswild( name )
   char *name;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
 	return(strchr(name,'*')	 ||  strchr(name,'%')  ||  strsub(name,"..."));
 }
 
 /* Usually used to simplify argv[0]. */
 static char *
-#if STDC
+#if defined(HAVE_STDC)
 nameonly(
   char *file
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 nameonly( file )
   char *file;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
   char *cp = file, *tp;
 #ifdef VMS
@@ -609,7 +598,7 @@ nameonly( file )
 	if(  tp = strchr(cp,'.')  )	/* Remove extension and/or... */
 		*tp = '\0';		/*  alternate form for version */
 #else  /* NOT VMS */
-	/* cp = strrchrb(cp,'/'); may be useful on other than MS-DOS */
+	/* cp = strrchr(cp,'/'); may be useful on other than MS-DOS */
 #ifdef MSDOS	/* Like this would ever be run under MS-DOS! */
 	tp = strrchr(cp,'/');		/* Skip Un*x path */
 	tp = tp ? tp+1 : cp;
@@ -623,14 +612,14 @@ nameonly( file )
 }
 
 static char*
-#if STDC
+#if defined(HAVE_STDC)
 normalize_filename(
 char	*filename		/* with logical names expanded */
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 normalize_filename(filename)	/* return lower-case copy of normalized name */
 char	*filename;		/* with logical names expanded */
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
     char	*logname;
     char	*p;
@@ -638,7 +627,7 @@ char	*filename;		/* with logical names expanded */
 
     p = strchr(filename,':');	/* do we have a logical name? */
     if (p != (char*)NULL)
-    {				/* yes, have to translate it interatively */
+    {				/* yes, have to translate it interactively */
 	logname = expand_logical(filename);
 	q = emalloc(strlen(p+1) + strlen(logname) + 1);
 	(void)strcpy(q,logname);
@@ -660,14 +649,14 @@ char	*filename;		/* with logical names expanded */
 
 /* Returns the next file name matching the specified wildcard. */
 static char *	/* Returns a pointer to an malloc()ed expanded filename */
-#if STDC
+#if defined(HAVE_STDC)
 nxt_wld(
   char	*wild	/* Wildcard to be expanded. */
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 nxt_wld( wild ) /* Returns 0 if all matching filenames have been returned. */
   char	*wild;	/* Wildcard to be expanded. */
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
     desc_str( wlddsc, wild );	/* VMS descriptor of wildcard string. */
     static uint cntxt = 0;	/* Context of wildcard search. */
@@ -692,7 +681,7 @@ nxt_wld( wild ) /* Returns 0 if all matching filenames have been returned. */
 	if (lencwd > 0)
 	{
 	    newcwd = normalize_filename(cwd);
-	    free(cwd);
+	    FREE(cwd);
 	    cwd = newcwd;
 	    lencwd = strlen(cwd);
 	}
@@ -701,7 +690,7 @@ nxt_wld( wild ) /* Returns 0 if all matching filenames have been returned. */
     stat = lib$find_file( &wlddsc, &fildsc, &cntxt, 0, 0, 0, &two );
     if (  rms$_syn == stat )
     {				/* File syntax error: */
-	fprintf( stderr, "%s: Invalid file wildcard.\n", wild );
+	(void)fprintf( stderr, "%s: Invalid file wildcard.\n", wild );
     }
     else if (  rms$_fnf != stat  &&  rms$_nmf != stat )
     {
@@ -720,7 +709,7 @@ nxt_wld( wild ) /* Returns 0 if all matching filenames have been returned. */
 
     p = normalize_filename(file);
     (void)strcpy(file,p);
-    free(p);
+    FREE(p);
     if (strsub(wild,";") == (char*)NULL) /* strip generation numbers too */
     {
 	p = strrchr(file,';');
@@ -746,16 +735,16 @@ nxt_wld( wild ) /* Returns 0 if all matching filenames have been returned. */
 /* Accepts argument beginning "{" and parses the options listed before the
  * closing "}". */
 static char **		/* Returns new value of `inpv'. */
-#if STDC
+#if defined(HAVE_STDC)
 parse_opt(
   int *ainpc,
   char **inpv
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 parse_opt( ainpc, inpv )
   int *ainpc;
   char **inpv;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
 	/* code to be added later */
 	return( inpv );
@@ -763,16 +752,16 @@ parse_opt( ainpc, inpv )
 
 /* Read additional command line arguments: */
 static char **
-#if STDC
+#if defined(HAVE_STDC)
 read_cmd_lin(
   int *ainpc,
   char **inpv
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 read_cmd_lin( ainpc, inpv )
   int *ainpc;
   char **inpv;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
   int midc;
   char **midv, line[4096], *ap, *cp, c;
@@ -798,18 +787,18 @@ read_cmd_lin( ainpc, inpv )
 
 /* Prompt for a string from SYS$INPUT: */
 static char *
-#if STDC
+#if defined(HAVE_STDC)
 read_w_prompt(
   char *prompt, /* String to prompt user with */
   char *buff,	/* Pointer to buffer to store the string that is read */
   int size	/* Size of *buff */
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 read_w_prompt( prompt, buff, size )
   char *prompt; /* String to prompt user with */
   char *buff;	/* Pointer to buffer to store the string that is read */
   int size;	/* Size of *buff */
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
   desc_str( pdsc, prompt );
   struct descr bdsc = { size-1, dsc$k_dtype_t, dsc$k_class_s, buff };
@@ -827,7 +816,7 @@ read_w_prompt( prompt, buff, size )
 
 /* Aspects of redirection common to both ">" (and variants) and "<": */
 static char **				/* Returns new value for `inpv'. */
-#if STDC
+#if defined(HAVE_STDC)
 redir(
   int *ainpc,
   char **inpv,
@@ -837,7 +826,7 @@ redir(
   char *lnm,	/* logical name:  "SYS$INPUT:" or "SYS$OUTPUT:" */
   char *acc	/* file access:	 "r", "w", or "a" */
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 redir( ainpc, inpv, fp, io, tok, lnm, acc )
   int *ainpc;
   char **inpv;
@@ -846,13 +835,13 @@ redir( ainpc, inpv, fp, io, tok, lnm, acc )
   char *tok;	/* ", `<'" or " (`>', `>>', `>&', or `>>&')" */
   char *lnm;	/* logical name:  "SYS$INPUT:" or "SYS$OUTPUT:" */
   char *acc;	/* file access:	 "r", "w", or "a" */
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
-  uint stat = 0;	/* Assume we wouldnn't reassign `lnm'. */
+  uint stat = 0;	/* Assume we wouldn't reassign `lnm'. */
 	if(  !**inpv  )		/* Not ">file" / "<file", must be... */
 		--*ainpc,  ++inpv;		/* ... "> file" / "< file". */
 	if(  !*inpv  ||	 !**inpv  ) {
-		fprintf( stderr,
+		(void)fprintf( stderr,
 		  "Invalid null %sput redirection%s.\n", io, tok );
 		if(  *ainpc == 0  )	/* Fell off end of argument list: */
 			++*ainpc,  --inpv;
@@ -860,14 +849,14 @@ redir( ainpc, inpv, fp, io, tok, lnm, acc )
 	}
 	if(  strchr( *inpv, '*' )  ||  strchr( *inpv, '%' )
 	 ||  strsub( *inpv, "..." )  ) {
-		fprintf( stderr, "Wildcards (%s) illegal in redirection%s.\n",
-		  *inpv, tok );
+		(void)fprintf( stderr,
+		    "Wildcards (%s) illegal in redirection%s.\n", *inpv, tok );
 		return( inpv );
 	}
 	*strchr( lnm, ':' ) = '\0';	/* Remove trailing colon. */
 	if(  strchr( *inpv, '/' )  ||  strsub( *inpv, ".." )  ) {
 		if(  OPdebug  )
-			fprintf( stderr, "%s %s %s (%s).\n",
+			(void)fprintf( stderr, "%s %s %s (%s).\n",
 			 "Warning:  Can't reassign", lnm,
 			 "to Un*x-style file name", *inpv );
 	} else {
@@ -879,7 +868,8 @@ redir( ainpc, inpv, fp, io, tok, lnm, acc )
 	if(  !freopen( odd(stat) ? lnm : *inpv, acc, fp )  ) {
 	/* if(	!( odd(stat) && freopen(lnm,acc,fp) )
 	 &&  !freopen(*inpv,acc,fp)  ) { */
-		fprintf( stderr, "Can't open \"%s\" as `std%s'.\n", *inpv, io );
+		(void)fprintf( stderr, "Can't open \"%s\" as `std%s'.\n",
+		    *inpv, io );
 		/* perror( *inpv ); */
 		exit( vaxc$errno );
 	}
@@ -888,34 +878,36 @@ redir( ainpc, inpv, fp, io, tok, lnm, acc )
 
 /* Redirects `stdin': */
 static char **
-#if STDC
+#if defined(HAVE_STDC)
 redirin(
   int *ainpc,
   char **inpv
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 redirin( ainpc, inpv )
   int *ainpc;
   char **inpv;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
+	static char sysinput[] = "SYS$INPUT:";	/* must be modifiable */
 	++*inpv;	/* Skip over the '<'. */
-	return(redir( ainpc, inpv, stdin, "in", ", `<'", "SYS$INPUT:", "r" ));
+	return(redir( ainpc, inpv, stdin, "in", ", `<'", sysinput, "r" ));
 }
 
 /* Redirects `stdout': */
 static char **
-#if STDC
+#if defined(HAVE_STDC)
 redirout(
   int *ainpc,
   char **inpv
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 redirout( ainpc, inpv )
   int *ainpc;
   char **inpv;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
+  static char sysoutput[] = "SYS$OUTPUT:";	/* must be modifiable */
   bool err = 0;		/* Assume not ">&" nor ">>&". */
   char *acc = "w";	/* Assume ">" (write) not ">>" (append). */
 	if(  '>' == *++*inpv  )		/* Append to output file: */
@@ -923,7 +915,7 @@ redirout( ainpc, inpv )
 	if(  '&' == **inpv  )		/* Redirect `stderr' as well: */
 		++*inpv,  err = 1;
 	inpv = redir( ainpc, inpv, stdout, "out",
-	  " (`>', `>>', `>&', or `>>&')", "SYS$OUTPUT:", acc );
+	  " (`>', `>>', `>&', or `>>&')", sysoutput, acc );
 	/* The following is harmless if redir() failed: */
 	if(  err  ) {
 		if(  !strchr( *inpv, '/' )  &&	!strsub( *inpv, ".." )	) {
@@ -939,14 +931,14 @@ redirout( ainpc, inpv )
 /* Signals any non-boring condition values so that error/warning messages
  * will be displayed. */
 static void
-#if STDC
+#if defined(HAVE_STDC)
 sigvms(
   uint stat
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 sigvms( stat )
   uint stat;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
   extern void lib$signal();
 	if(  ( stat & 0xffff ) == 1 )
@@ -957,16 +949,16 @@ sigvms( stat )
 /* Returns the position of a substring within a string.	 Should be replaced by
  * strstr() when DEC provides one. */
 static char *
-#if STDC
+#if defined(HAVE_STDC)
 strsub(
   char *str,
   char *sub
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 strsub( str, sub )
   char *str;
   char *sub;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
   register char *fp = sub;	/* Points to character we hope to Find next */
   char *sp = strchr(str,*fp);	/* Points to current Starting character */
@@ -984,16 +976,16 @@ strsub( str, sub )
 #ifdef TEST
 
 /* Displays a string to `stdout', making all control and meta characters
- * printable unambigously. */
+ * printable unambiguously. */
 static void
-#if STDC
+#if defined(HAVE_STDC)
 dump(
   char *str
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 dump( str )
   char *str;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
 # define META '`'	/* Show 'a'+'\200' as "`a" */
 # define CTRL '^'	/* Show '\001' as "^A" */
@@ -1027,27 +1019,28 @@ dump( str )
 }
 
 int
-#if STDC
+#if defined(HAVE_STDC)
 main(
   int argc,
   char **argv
 )
-#else /* NOT STDC */
+#else /* NOT defined(HAVE_STDC) */
 main( argc, argv )
   int argc;
   char **argv;
-#endif /* STDC */
+#endif /* defined(HAVE_STDC) */
 {
     int cnt;
     extern char **cmd_lin();
 
     argv = cmd_lin( "", &argc, argv );
-    printf( "%d argument%s%s\n", argc, 1==argc ? "" : "s", argc ? ":" : "." );
+    (void)printf( "%d argument%s%s\n",
+	argc, 1==argc ? "" : "s", argc ? ":" : "." );
     for(  cnt = 0; *argv; ++argv )
     {
-	printf( "%5d: `", ++cnt );
+	(void)printf( "%5d: `", ++cnt );
 	dump( *argv );
-	printf( "'\n" );
+	(void)printf( "'\n" );
     }
     exit(EXIT_SUCCESS);
     return(0);
